%% Hartz III net of growth
% parametrs from the pre-reform steady state
    clear; load GE.mat;
% starting
    diary ('GE_Hartz_psi_1061_1229_net.txt'); diary on; tic;
    for k = 1:K; fprintf('graw_solve_GE: productivity of skill-type %g: %g and cost of vacancy: %g\n',k, VarData(2,k),gamma(k)); end;
    
%% search for GE
% a) psi
    InvData(18) = 1.061; % psi_UI
    InvData(19) = 1.229; % psi_UA
% b) pure impact of Hartz III (net of growth in 2004 realtive to 2003)
    A = VarData(2,:);
% initial contidiotns
    wage0 = VarData(1,1:K); theta0 = VarData(7,1:K); y0 = [wage0,theta0];
% flags
	AwFlag = 2; % block 2 is solved for wk theta and kappa
    ChoiceVarData = 1; % 1 - gives the real variable data, 2 - data for testing the monotonicity

% start fsolve
    matlabpool open local 6;
    [wTheta,preci,exitflagBlock2] = fsolve('block2',y0,optimset('Display','iter'),InvData,VarData,K);
    matlabpool close;
    
    wage = wTheta(1:K);     theta = wTheta(K+1:2*K); 
    VarData(1,1:K) = wage;  VarData(7,1:K) = theta; % save results in VarData such that it is used e.g. in block 1 below
    
    disp('GE solved for Hartz III');
    for k = 1:K; fprintf('solve_GE: wage of worker-type k = %g (at productivity: %g)\n', wage(k),VarData(2,k)); end;
    fprintf('solve_GE: tightness (theta): %g\n', theta);    disp(' ');
    fprintf('solve_GE: precision of fsolve: %g\n',preci);   disp(' ');
    fprintf('exitflag of block2: %g\n',exitflagBlock2);     disp(' ');
    
% compute corresponding block 1 values    
    [employmentVector,UshortVector,UlongVector,mueIniVector,effortIniVector,mueBarVector,V0,Vbs,Vw,EU] = KtimesBlock1(InvData,VarData,K);

% complete block 2
    lambda = VarData(6,:); xiUI = VarData(8); xiUA = InvData(16);
    
    kappa = taxrate(wage,employmentVector,xiUI,UshortVector,xiUA,UlongVector);	disp('kappa');  disp(kappa);    
    J = (A - wage/(1-kappa))./(rho + lambda);                                   disp('J');      disp(J);
        
% save all
	save GE_H3_1061_1229_net; clear;
        
        
%% Hartz III + IV net of growth
% parametrs from the steady state after Hartz III
    load GE_H3_1061_1229_net.mat;
% starting
    for k = 1:K; fprintf('solve_GE: productivity of skill-type %g: %g and cost of vacancy: %g\n',k, VarData(2,k),gamma(k)); end;
    
%% search for GE
    xiUA = InvData(16); VarData(11,:) = xiUA * VarData(1,1:K); 
    if K == 6;
        % a) benefits
            VarData(11,:) = VarData(11,:) .* [.95 .95 1.15 .7 .95 1.3]; % direct bUA reduction due to Hartz IV
            VarData(9,:) = VarData(9,:) - [3 1 1 1 2 2];                % direct sBar reduction due to Hartz IV
        % b) pure impact of Hartz III (net of growth in 2005 realtive to 2004)
            A = VarData(2,:);
    elseif K == 1;
        % a) benefits
            VarData(11,:) = VarData(11,:) .* .975; % direct bUA reduction due to Hartz IV
            VarData(9,:) = VarData(9,:) - 1;       % direct sBar reduction due to Hartz IV
        % b) pure impact of Hartz III (net of growth in 2005 realtive to 2004)
            A = VarData(2,:);
    end;
% initial conditions
    InvData(17) = 2; % take direct reduction due to Hartz IV as specified above through setting the 'round' value = 2
    wage0 = VarData(1,1:K); theta0 = VarData(7,1:K); y0 = [wage0,theta0];
    
    disp(VarData(4:5,:)); disp(InvData(17:cols(InvData))); % check for Hartz III and IV
% flags
	AwFlag = 2; % block 2 is solved for wk theta and kappa
    ChoiceVarData = 1; % 1 - gives the real variable data, 2 - data for testing the monotonicity

% start fsolve
    matlabpool open local 6;
    [wTheta,preci,exitflagBlock2] = fsolve('block2',y0,optimset('Display','iter'),InvData,VarData,K);
    matlabpool close;
    
    wage = wTheta(1:K); theta = wTheta(K+1:2*K);    
    VarData(1,1:K) = wage; VarData(7,1:K) = theta; % save results in VarData such that it is used e.g. in block 1 below
    
    disp('GE solved for Hartz IV after Hartz III');
    for k = 1:K; fprintf('solve_GE: wage of worker-type k = %g (at productivity: %g)\n', wage(k),VarData(2,k)); end;
    fprintf('solve_GE: tightness (theta): %g\n', theta);	disp(' ');
    fprintf('solve_GE: precision of fsolve: %g\n',preci);	disp(' ');
    fprintf('exitflag of block2: %g\n',exitflagBlock2);     disp(' ');
    
% compute corresponding block 1 values      
    [employmentVector,UshortVector,UlongVector,mueIniVector,effortIniVector,mueBarVector,V0,Vbs,Vw,EU] = KtimesBlock1(InvData,VarData,K);

% complete block 2
    lambda = VarData(6,:); xiUI = VarData(8); xiUA = InvData(16);
    
    kappa = taxrate(wage,employmentVector,xiUI,UshortVector,xiUA,UlongVector);	disp('kappa');  disp(kappa);    
    J = (A - wage/(1-kappa))./(rho + lambda);                                   disp('J');      disp(J);
        
% save all
        save GE_H34_1061_1229_net; clear;
        
    
% conclusion    
    toc; if toc>60; fprintf('elapsed time is %g minutes\n',toc/60); end;
    if toc>3600; fprintf('elapsed time is %g hours\n',toc/3600); end;
    
% bye bye
    diary off;