%%
%%
%% Instructions
%  This is the file which for the given values of psi_UI and psi_UA
%  generates the series of matches, unemployment and vacancies and saves
%  these in a form of the matrix X_AAAA_BBBB.raw in the subdirectory
%  "\auxiregs".
%  To run this file replace AAAA and BBBB throughout the whole file as well
%  as A.AAA and B.BBB in lines 22 and 23 by the desired values of psi_UI
%  and psi_UA. Run the file and look in the folder "\auxiregs" for output.
%%
%%
%% Hartz III + growth
% parametrs from the pre-reform steady state
    clear; load GE.mat;
% starting
    diary ('GE_Hartz_psi_AAAA_BBBB_growth.txt'); diary on; tic;
    for k = 1:K; fprintf('graw_solve_GE: productivity of skill-type %g: %g and cost of vacancy: %g\n',k, VarData(2,k),gamma(k)); end;
    
%% search for GE
% a) psi
    InvData(18) = A.AAA; % e.g. InvData(18) = 1.076; % this is psi_UI
    InvData(19) = B.BBB; % e.g. InvData(19) = 1.230; % this is psi_UA
% b) growth in 2004 realtive to 2003
    VarData(2,:) = 1.00840 * VarData(2,:);  A = VarData(2,:);
% initial contidiotns
    wage0 = VarData(1,1:K); theta0 = VarData(7,1:K); y0 = [wage0,theta0];
% flags
	AwFlag = 2; % block 2 is solved for wk theta and kappa
    ChoiceVarData = 1; % 1 - gives the real variable data, 2 - data for testing the monotonicity

% start fsolve
    matlabpool open local 6;
    [wTheta,preci,exitflagBlock2] = fsolve('block2',y0,optimset('Display','iter'),InvData,VarData,K);
    matlabpool close;
    
    wage = wTheta(1:K);     theta = wTheta(K+1:2*K); 
    VarData(1,1:K) = wage;  VarData(7,1:K) = theta; % save results in VarData such that it is used e.g. in block 1 below
    
    disp('GE solved for Hartz III and growth');
    for k = 1:K; fprintf('solve_GE: wage of worker-type k = %g (at productivity: %g)\n', wage(k),VarData(2,k)); end;
    fprintf('solve_GE: tightness (theta): %g\n', theta);    disp(' ');
    fprintf('solve_GE: precision of fsolve: %g\n',preci);   disp(' ');
    fprintf('exitflag of block2: %g\n',exitflagBlock2);     disp(' ');
    
% compute corresponding block 1 values    
    [employmentVector,UshortVector,UlongVector,mueIniVector,effortIniVector,mueBarVector,V0,Vbs,Vw,EU] = KtimesBlock1(InvData,VarData,K);

% complete block 2
    lambda = VarData(6,:); xiUI = VarData(8); xiUA = InvData(16);
    
    kappa = taxrate(wage,employmentVector,xiUI,UshortVector,xiUA,UlongVector);	disp('kappa');  disp(kappa);    
    J = (A - wage/(1-kappa))./(rho + lambda);                                   disp('J');      disp(J);
        
% save all
	save GE_H3_AAAA_BBBB_gr2004; clear;
        
        
%% After Hartz and before the Great Recession: 2005
% parametrs from the steady state after Hartz III
    load GE_H3_AAAA_BBBB_gr2004.mat;
% starting
    for k = 1:K; fprintf('solve_GE: productivity of skill-type %g: %g and cost of vacancy: %g\n',k, VarData(2,k),gamma(k)); end;
    
%% search for GE
% a) growth in 2005 realtive to 2004
	VarData(2,:) = 1.01203 * VarData(2,:);  A = VarData(2,:);
% initial conditions
    wage0 = VarData(1,1:K); theta0 = VarData(7,1:K); y0 = [wage0,theta0]; % disp(InvData(17:cols(InvData)));
% flags
	AwFlag = 2; % block 2 is solved for wk theta and kappa
    ChoiceVarData = 1; % 1 - gives the real variable data, 2 - data for testing the monotonicity

% start fsolve
    matlabpool open local 6;
    [wTheta,preci,exitflagBlock2] = fsolve('block2',y0,optimset('Display','iter'),InvData,VarData,K);
    matlabpool close;
    
    wage = wTheta(1:K); theta = wTheta(K+1:2*K);    
    VarData(1,1:K) = wage; VarData(7,1:K) = theta; % save results in VarData such that it is used e.g. in block 1 below
    
    disp('GE solved for post Hartz III: 2005');
    for k = 1:K; fprintf('solve_GE: wage of worker-type k = %g (at productivity: %g)\n', wage(k),VarData(2,k)); end;
    fprintf('solve_GE: tightness (theta): %g\n', theta);	disp(' ');
    fprintf('solve_GE: precision of fsolve: %g\n',preci);	disp(' ');
    fprintf('exitflag of block2: %g\n',exitflagBlock2);     disp(' ');
    
% compute corresponding block 1 values      
    [employmentVector,UshortVector,UlongVector,mueIniVector,effortIniVector,mueBarVector,V0,Vbs,Vw,EU] = KtimesBlock1(InvData,VarData,K);

% complete block 2
    lambda = VarData(6,:); xiUI = VarData(8); xiUA = InvData(16);
    
    kappa = taxrate(wage,employmentVector,xiUI,UshortVector,xiUA,UlongVector);	disp('kappa');  disp(kappa);    
    J = (A - wage/(1-kappa))./(rho + lambda);                                   disp('J');      disp(J);
        
% save all
        save GE_postH3_AAAA_BBBB_gr2005; clear;
    
        
%% After Hartz and before the Great Recession: 2006
% parametrs from the steady state after Hartz III
    load GE_postH3_AAAA_BBBB_gr2005.mat;
% starting
    for k = 1:K; fprintf('solve_GE: productivity of skill-type %g: %g and cost of vacancy: %g\n',k, VarData(2,k),gamma(k)); end;
    
%% search for GE
% a) growth in 2006 relative to 2005
    VarData(2,:) = 1.03639 * VarData(2,:);  A = VarData(2,:);
% initial contidiotns
    wage0 = VarData(1,1:K); theta0 = VarData(7,1:K); y0 = [wage0,theta0];
% flags
	AwFlag = 2; % block 2 is solved for wk theta and kappa
    ChoiceVarData = 1; % 1 - gives the real variable data, 2 - data for testing the monotonicity

% start fsolve
    matlabpool open local 6;
    [wTheta,preci,exitflagBlock2] = fsolve('block2',y0,optimset('Display','iter'),InvData,VarData,K);
    matlabpool close;
    
    wage = wTheta(1:K); theta = wTheta(K+1:2*K);    
    VarData(1,1:K) = wage; VarData(7,1:K) = theta; % save results in VarData such that it is used e.g. in block 1 below
    
    disp('GE solved for post Hartz III: 2006');
    for k = 1:K; fprintf('solve_GE: wage of worker-type k = %g (at productivity: %g)\n', wage(k),VarData(2,k)); end;
    fprintf('solve_GE: tightness (theta): %g\n', theta);    disp(' ');
    fprintf('solve_GE: precision of fsolve: %g\n',preci);   disp(' ');
    fprintf('exitflag of block2: %g\n',exitflagBlock2);     disp(' ');
    
% compute corresponding block 1 values
    [employmentVector,UshortVector,UlongVector,mueIniVector,effortIniVector,mueBarVector,V0,Vbs,Vw,EU] = KtimesBlock1(InvData,VarData,K);

% complete block 2
    lambda = VarData(6,:); xiUI = VarData(8); xiUA = InvData(16);
    
    kappa = taxrate(wage,employmentVector,xiUI,UshortVector,xiUA,UlongVector);	disp('kappa');  disp(kappa);    
    J = (A - wage/(1-kappa))./(rho + lambda);                                   disp('J');      disp(J);
         
% save all
        save GE_postH3_AAAA_BBBB_gr2006; clear;
    
        
%% After Hartz and before the Great Recession: 2007
% parametrs from the steady state after Hartz III
    load GE_postH3_AAAA_BBBB_gr2006.mat;
% starting
    for k = 1:K; fprintf('solve_GE: productivity of skill-type %g: %g and cost of vacancy: %g\n',k, VarData(2,k),gamma(k)); end;
    
%% search for GE
% a) growth in 2007 relative to 2006
    VarData(2,:) = 1.01682 * VarData(2,:);  A = VarData(2,:);
% initial contidiotns
    wage0 = VarData(1,1:K); theta0 = VarData(7,1:K); y0 = [wage0,theta0];
% flags
	AwFlag = 2; % block 2 is solved for wk theta and kappa
    ChoiceVarData = 1; % 1 - gives the real variable data, 2 - data for testing the monotonicity

% start fsolve
    matlabpool open local 6;
    [wTheta,preci,exitflagBlock2] = fsolve('block2',y0,optimset('Display','iter'),InvData,VarData,K);
    matlabpool close;
    
    wage = wTheta(1:K); theta = wTheta(K+1:2*K);    
    VarData(1,1:K) = wage; VarData(7,1:K) = theta; % save results in VarData such that it is used e.g. in block 1 below
    
    disp('GE solved for post Hartz III: 2007');
    for k = 1:K; fprintf('solve_GE: wage of worker-type k = %g (at productivity: %g)\n', wage(k),VarData(2,k)); end;
    fprintf('solve_GE: tightness (theta): %g\n', theta);    disp(' ');
    fprintf('solve_GE: precision of fsolve: %g\n',preci);   disp(' ');
    fprintf('exitflag of block2: %g\n',exitflagBlock2);     disp(' ');
    
% compute corresponding block 1 values
    [employmentVector,UshortVector,UlongVector,mueIniVector,effortIniVector,mueBarVector,V0,Vbs,Vw,EU] = KtimesBlock1(InvData,VarData,K);

% complete block 2
    lambda = VarData(6,:); xiUI = VarData(8); xiUA = InvData(16);
    
    kappa = taxrate(wage,employmentVector,xiUI,UshortVector,xiUA,UlongVector);	disp('kappa');  disp(kappa);    
    J = (A - wage/(1-kappa))./(rho + lambda);                                   disp('J');      disp(J);
         
% save all
        save GE_postH3_AAAA_BBBB_gr2007; clear;
    
        
%% After Hartz and before the Great Recession: 2008
% parametrs from the steady state after Hartz III
    load GE_postH3_AAAA_BBBB_gr2007.mat;
% starting
    for k = 1:K; fprintf('solve_GE: productivity of skill-type %g: %g and cost of vacancy: %g\n',k, VarData(2,k),gamma(k)); end;
    
%% search for GE
% a) growth in 2008 relative to 2007
    VarData(2,:) = 0.99880 * VarData(2,:);  A = VarData(2,:);
% initial contidiotns
    wage0 = VarData(1,1:K); theta0 = VarData(7,1:K); y0 = [wage0,theta0];
% flags
	AwFlag = 2; % block 2 is solved for wk theta and kappa
    ChoiceVarData = 1; % 1 - gives the real variable data, 2 - data for testing the monotonicity

% start fsolve
    matlabpool open local 6;
    [wTheta,preci,exitflagBlock2] = fsolve('block2',y0,optimset('Display','iter'),InvData,VarData,K);
    matlabpool close;
    
    wage = wTheta(1:K); theta = wTheta(K+1:2*K);    
    VarData(1,1:K) = wage; VarData(7,1:K) = theta; % save results in VarData such that it is used e.g. in block 1 below
    
    disp('GE solved for post Hartz III: 2008');
    for k = 1:K; fprintf('solve_GE: wage of worker-type k = %g (at productivity: %g)\n', wage(k),VarData(2,k)); end;
    fprintf('solve_GE: tightness (theta): %g\n', theta);    disp(' ');
    fprintf('solve_GE: precision of fsolve: %g\n',preci);   disp(' ');
    fprintf('exitflag of block2: %g\n',exitflagBlock2);     disp(' ');
    
% compute corresponding block 1 values
    [employmentVector,UshortVector,UlongVector,mueIniVector,effortIniVector,mueBarVector,V0,Vbs,Vw,EU] = KtimesBlock1(InvData,VarData,K);

% complete block 2
    lambda = VarData(6,:); xiUI = VarData(8); xiUA = InvData(16);
    
    kappa = taxrate(wage,employmentVector,xiUI,UshortVector,xiUA,UlongVector);	disp('kappa');  disp(kappa);    
    J = (A - wage/(1-kappa))./(rho + lambda);                                   disp('J');      disp(J);
         
% save all
        save GE_postH3_AAAA_BBBB_gr2008; clear;

        
%% Create the data matrix
format('short','g');

load GE_PRSS_gr2000;
V=(UshortVector'+UlongVector').*theta'; Mshort=mueBarVector'.*UshortVector'; Mlong=mueBarVector'.*UlongVector';
dmx_2000=[2000*ones(6,1),(1:1:6)',AAAA*ones(6,1)/1000,BBBB*ones(6,1)/1000,log(Mshort),log(Mlong),log(UshortVector'),log(UlongVector'),log(V),zeros(6,1)];
save('X_AAAA_BBBB.mat','dmx_2000'); clear;

load GE_PRSS_gr2001;
V=(UshortVector'+UlongVector').*theta'; Mshort=mueBarVector'.*UshortVector'; Mlong=mueBarVector'.*UlongVector';
dmx_2001=[2001*ones(6,1),(1:1:6)',AAAA*ones(6,1)/1000,BBBB*ones(6,1)/1000,log(Mshort),log(Mlong),log(UshortVector'),log(UlongVector'),log(V),zeros(6,1)];
load X_AAAA_BBBB; save('X_AAAA_BBBB.mat','dmx_2000','dmx_2001'); clear;

load GE_PRSS_gr2002;
V=(UshortVector'+UlongVector').*theta'; Mshort=mueBarVector'.*UshortVector'; Mlong=mueBarVector'.*UlongVector';
dmx_2002=[2002*ones(6,1),(1:1:6)',AAAA*ones(6,1)/1000,BBBB*ones(6,1)/1000,log(Mshort),log(Mlong),log(UshortVector'),log(UlongVector'),log(V),zeros(6,1)];
load X_AAAA_BBBB; save('X_AAAA_BBBB.mat','dmx_2000','dmx_2001','dmx_2002'); clear;

load GE;
V=(UshortVector'+UlongVector').*theta'; Mshort=mueBarVector'.*UshortVector'; Mlong=mueBarVector'.*UlongVector';
dmx_2003=[2003*ones(6,1),(1:1:6)',AAAA*ones(6,1)/1000,BBBB*ones(6,1)/1000,log(Mshort),log(Mlong),log(UshortVector'),log(UlongVector'),log(V),zeros(6,1)];
load X_AAAA_BBBB; save('X_AAAA_BBBB.mat','dmx_2000','dmx_2001','dmx_2002','dmx_2003'); clear;

load GE_H3_AAAA_BBBB_gr2004.mat;
V=(UshortVector'+UlongVector').*theta'; Mshort=mueBarVector'.*UshortVector'; Mlong=mueBarVector'.*UlongVector';
dmx_2004=[2004*ones(6,1),(1:1:6)',AAAA*ones(6,1)/1000,BBBB*ones(6,1)/1000,log(Mshort),log(Mlong),log(UshortVector'),log(UlongVector'),log(V),ones(6,1)];
load X_AAAA_BBBB; save('X_AAAA_BBBB.mat','dmx_2000','dmx_2001','dmx_2002','dmx_2003','dmx_2004'); clear;

load GE_postH3_AAAA_BBBB_gr2005.mat;
V=(UshortVector'+UlongVector').*theta'; Mshort=mueBarVector'.*UshortVector'; Mlong=mueBarVector'.*UlongVector';
dmx_2005=[2005*ones(6,1),(1:1:6)',AAAA*ones(6,1)/1000,BBBB*ones(6,1)/1000,log(Mshort),log(Mlong),log(UshortVector'),log(UlongVector'),log(V),ones(6,1)];
load X_AAAA_BBBB; save('X_AAAA_BBBB.mat','dmx_2000','dmx_2001','dmx_2002','dmx_2003','dmx_2004','dmx_2005'); clear;

load GE_postH3_AAAA_BBBB_gr2006.mat;
V=(UshortVector'+UlongVector').*theta'; Mshort=mueBarVector'.*UshortVector'; Mlong=mueBarVector'.*UlongVector';
dmx_2006=[2006*ones(6,1),(1:1:6)',AAAA*ones(6,1)/1000,BBBB*ones(6,1)/1000,log(Mshort),log(Mlong),log(UshortVector'),log(UlongVector'),log(V),ones(6,1)];
load X_AAAA_BBBB; save('X_AAAA_BBBB.mat','dmx_2000','dmx_2001','dmx_2002','dmx_2003','dmx_2004','dmx_2005','dmx_2006'); clear;

load GE_postH3_AAAA_BBBB_gr2007.mat;
V=(UshortVector'+UlongVector').*theta'; Mshort=mueBarVector'.*UshortVector'; Mlong=mueBarVector'.*UlongVector';
dmx_2007=[2007*ones(6,1),(1:1:6)',AAAA*ones(6,1)/1000,BBBB*ones(6,1)/1000,log(Mshort),log(Mlong),log(UshortVector'),log(UlongVector'),log(V),ones(6,1)];
load X_AAAA_BBBB; save('X_AAAA_BBBB.mat','dmx_2000','dmx_2001','dmx_2002','dmx_2003','dmx_2004','dmx_2005','dmx_2006','dmx_2007'); clear;

load GE_postH3_AAAA_BBBB_gr2008.mat;
V=(UshortVector'+UlongVector').*theta'; Mshort=mueBarVector'.*UshortVector'; Mlong=mueBarVector'.*UlongVector';
dmx_2008=[2008*ones(6,1),(1:1:6)',AAAA*ones(6,1)/1000,BBBB*ones(6,1)/1000,log(Mshort),log(Mlong),log(UshortVector'),log(UlongVector'),log(V),ones(6,1)];
load X_AAAA_BBBB; save('X_AAAA_BBBB.mat','dmx_2000','dmx_2001','dmx_2002','dmx_2003','dmx_2004','dmx_2005','dmx_2006','dmx_2007','dmx_2008'); clear;

load X_AAAA_BBBB; X_AAAA_BBBB=[dmx_2000;dmx_2001;dmx_2002;dmx_2003;dmx_2004;dmx_2005;dmx_2006;dmx_2007;dmx_2008]; 
save X_AAAA_BBBB.mat; save('auxiregs\X_AAAA_BBBB.raw','X_AAAA_BBBB','-ascii'); clear;


% conclusion    
    toc; if toc>60; fprintf('elapsed time is %g minutes\n',toc/60); end;
    if toc>3600; fprintf('elapsed time is %g hours\n',toc/3600); end;
    
% bye bye
    diary off;