function [employmentVector,UshortVector,UlongVector,mueIniVector,effortIniVector,mueBarVector,V0,Vbs,Vw,EU,sAvgVector,effort_path] = KtimesBlock1(InvData,VarData,K)
      
% flags
    genau = 1; % programm checking mode: genau = 0, computing results mode: genau = 1
    talk = 0; % should messages be displayed from this file? 1: yes
    showFig = 0; % should micro dynamics figures be displayed? 0: no
% paras   
    N       = VarData(3,:); % size vector for groups
    piHigh  = InvData(8); 
    round   = InvData(17);

% initialize
    infinity = InvData(13);
    effort_path = zeros(K,infinity);

parfor k = 1:K
%fprintf('KtimesBlock1: K = %g\n',K)
% solve block 1
    if talk == 1; fprintf('\nKtimesBlock1: Solve first partial (block 1) equilibrium. Group %g of %g in round %g\n', k, K,round); end
    [V0(k),VbUI(k),VbUA(k),Vw(k),pInfinity,sole_sp_fin] = block1(InvData,VarData(:,k),NaN,NaN,NaN); % sole_sp_fin is phi^alpha
    
% completing block 1 (solve what else we know from block 1)
    % job arrival rate mu, expected mu, effort phi...
        [mue,mue_int,mue_bar,Vbs(k,:),belief,f,phi,mue0_0,mue1_0,s_avg] = muebar(VbUI(k),VbUA(k),Vw(k),sole_sp_fin,InvData,VarData(:,k));

% Compute (un)employment (rates) for group k
    if genau == 1
        mue0 = mue(1,:); mue1 = mue(2,:);
        mue_int0 = mue_int(1,:); mue_int1 = mue_int(2,:);
        mue_bar0 = mue_bar(1); mue_bar1 = mue_bar(2);
        f0 = f(1,:); f1 = f(2,:);
        
        if talk == 1; fprintf('KtimesBlock1: average arrival rates for the unemployed: %g, %g\n', mue_bar0, mue_bar1); end
        if isnan(mue_bar0), error('KtimesBlock1 talking: too much NaN'), end

        % compute the number of unemployed for the low-productivity searchers
            N0 = N(k) * (1-piHigh); % piHigh is share of high-productivity searchers
            [U0,Ushort0,Ulong0] = unemployment(mue0',mue_int0,f0,mue0_0,N0,InvData,VarData(:,k)); % why prime? Because KW Oct 11
            % fprintf('just out of curiosity: is this zero at any time? %g',U0(k)-Ushort0-Ulong0)                    

        % compute the number of unemployed for the high-productivity searchers
            N1 = N(k) * piHigh;
            [U1,Ushort1,Ulong1] = unemployment(mue1',mue_int1,f1,mue1_0,N1,InvData,VarData(:,k));

    else
        disp('KtimesBlock1: XXXXXXXXXXXXXX programm running in program checking mode - no valid results XXXXXXXX')
        N0 = 3*10^6; N1 = 3*10^6;
        U0 = 2*10^6; Ushort0 = 1.5 *10^6; Ulong0 = .5*10^6;
        U1 = 2*10^6; Ushort1 = 1.5 *10^6; Ulong1 = .5*10^6;
        
    end

    U0_rate(k) = U0/N0; U0short_rate(k) = Ushort0/U0; U0long_rate(k) = Ulong0/U0;
    U1_rate(k) = U1/N1; U1short_rate(k) = Ushort1/U1; U1long_rate(k) = Ulong1/U1;

    if talk == 1; fprintf('KtimesBlock1: group %g unemployment rate low-prod: %g, high-prod: %g\n', k, U0_rate(k), U1_rate(k)); end
    if talk == 1; fprintf('KtimesBlock1: group %g long-term unemployment rate low-prod: %g, high-prod: %g\n', k, U0long_rate(k), U1long_rate(k)); end

% look at nice pictures
    if showFig == 1
        figure()
        cd '3 analyse'
        microdynamics(InvData,belief,phi,mue,Vbs(k,:))
        str=sprintf('Microresults_%d_%d', round, k);
        %saveas(gcf,str,'jpg')
        saveas(gcf,str,'eps')
        cd ..
        pause(.1)
    end
% collecting results
	EU_0 = welfare(InvData,VarData(:,k),f0,Vbs(k,:),Vw(k),U0+U1);
    EU_1 = welfare(InvData,VarData(:,k),f1,Vbs(k,:),Vw(k),U0+U1);
    EU(k) = (1-piHigh)*EU_0 + piHigh*EU_1; % welfare function (soc welfare k)
    employmentVector(k) = N(k) - U0 - U1;
    mueIniVector(k) = mue(3,1); % saving initial subjective exit rate
    effortIniVector(k) = phi(1); % save initial effort
    UshortVector(k) = Ushort0 + Ushort1;
    UlongVector(k) = Ulong0 + Ulong1;
    mueBarVector(k) = (1-piHigh) * mue_bar(1) + piHigh * mue_bar(2);
    sAvgVector(k) = (1-piHigh) * s_avg(1) + piHigh * s_avg(2);
    
% construct figure with effort for all groups in round 0 (microresults_0_1 graph): getting data
    effort_path(k,:)=phi;
    if round==0 
       belief_eff(k,:)=belief;
       mue_eff1(k,:)=mue(1,:);
       mue_eff2(k,:)=mue(2,:);
       mue_eff3(k,:)=mue(3,:);
    end
    
end

% some control messages
    uRate = sum(UshortVector+UlongVector)/sum(N);
    fprintf('\nKtimesBlock1: unemployment rate in economy with %g groups is %g%%\n',K, uRate*100);
    if talk == 1; fprintf('KtimesBlock1: average arrival rate (mueBar): %g\n',mueBarVector); end
    
% save data for figure with effort for all groups in round 0 (microresults_0_1 graph)
    if round==0
        disp('KtimesBlock1: round = 0, solving for PRSS')
        save('figure_PRSS','effort_path','belief_eff','mue_eff1','mue_eff2','mue_eff3','Vbs')
    end

end