%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
% This m-file calculates the probabilities for Puu(taumax,s) for different
% s and fills them into the Matrix Puu
% The probabilities are used in unemployment.m to compute unemployment
%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%

function [Puu]=smcPuu(InvData,VarData,mue,P,mueINIT)


    infinity = InvData(13); 

% extract parameters from imported data
    steps=infinity; h=1; 

% initialize vector Peu and matrix Puu
    Peu = P(:,1); Puu = P(:,2);

% initialize Peu(0)
    PeuINIT = 0;
    
% begin loop in order to compute the transition probabilities for the
% #steps type of unemployed. k is the column of the matrix Puu
% begin with k=2, i.e. the unemployed who has a unemployment spell s=h 
% at the beginning in t
    for k = 2:steps;

        % Integrals of mue for the different types of unemployed. integrate
        % numerically with trapeze method
            mue_int(1,k) = 0.5 * h * (mueINIT(1,k) + mue(1,k));
            for j = 2:steps;
                mue_int(j,k) = mue_int(j-1,k) + .5*h*(mue(j-1,k) + mue(j,k));
            end;
   
        % Now compute the transition probability according to the
        % transition probability equation for Puu(tau|s) in the paper.
        % The integrals are approximated by trapeze method
            for z = 1:steps;
                Puu(z,k) = exp(-mue_int(z,k))+.5*h*mueINIT(1,k)*Peu(z);
                for j = 1:z-1;
                    Puu(z,k) = Puu(z,k)+h*Peu(z-j,1)*mue(j,k)*exp(-mue_int(j,k));
                end;
            Puu(z,k) = Puu(z,k) + .5*h*exp(-mue_int(z,k))*mue(z,k)*PeuINIT;
            end;

    end;