%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
% Function that calculates Puu(taumax,s=0) and Peu(taumax) for different b2
% Solves Semi-Markov equation system from the paper numerically
% The probabilities are used in unemployment.m to compute unemployment
%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%

function P = smcprob(InvData,VarData,mue,mueINIT,mue_int)


    infinity = InvData(13); 
    
% extract parameters from imported data
    lambda = VarData(6); steps=infinity; h=1; 
    
% initialize matrix P in which all calculated values for Peu and Puu for 
% each step are collected. 
    % Peu(0)
        PeuINIT = 0;
	% Puu(0)
        PuuINIT = 1;      

% assume we have #steps discretization steps, so we have to solve 
% the equations for different time points successively in a loop, 
% begin with z=1
    P  = NaN(steps,2); % preallocating memory
    for z = 1:steps
        
    % The following loop calculates the integrals on the rhs of the
    % equations for Semi-Markov transition probabilities
    % Also here, the integrals are approximated by trapeze method.
        sumEU = 0;
        sumUU = exp(-mue_int(z));
        for j = 1:z-1;
            sumEU = sumEU+h*P(z-j,2)*lambda*exp(-lambda*j*h);
            sumUU = sumUU+h*P(z-j,1)*mue(j)*exp(-mue_int(j));
        end;
        sumEU = sumEU+.5*h*PuuINIT*lambda*exp(-lambda*(z)*h);
        sumUU = sumUU+.5*h*PeuINIT*mue(z)*exp(-mue_int(z));

    % define lhs of the equation system
         X = [1                     -.5*h*lambda
              -.5*h*mueINIT(1,1)    1           ];
    
    % define vector for the rhs of the equation system
        y= [sumEU
            sumUU];

    % calculate the probabilities by solving the linear equation system
        W = X\y;
 
     % Write the first element of the vector W (=Peu(z)) into first place 
     % of the next row of the P matrix and the second element of W (=Puu(z)) 
     % into the second place. This creates a matrix with transition
     % probabilities
        P(z,1)=W(1); P(z,2)=W(2);
    end;
