%% prelims by hand

% what to do in Block2tool
	AwFlag = 1;   % block 2 is solved for Ak gamma and kappa
    savePRSS = 1; % Block2tool saves PRSS

%% prelims

% count time    
    tic
    
% display time
    aux = clock; 
    fprintf('solve_PRSS: what time is it? It is %g:%g \n',aux(4),aux(5))
    
% InvData and VarData
    VarDataAux = InputVariableData;
    K0 = 1;  K1 = 6; % K0 first and K1 last row 
    K = K1 - K0 + 1; % fixes number of groups
    fprintf('KtimesBlock1: There are %g groups being analysed, including columns %g to %g\n',K,K0,K1);
    VarData = VarDataAux(:,K0:K1); % load only columns K0 to K1
    
	InvData = InputInvariantData;

    if K0 == 8 % if we analyse unconditional model
        disp('analysis of unconditional model')
        alpha   = 0.4059;               
        sigma   = 0.7639; 
        pIni    = 0.5000;
        piHigh  = 0.9246;
        piPass  = 0.2447;
        
        %             1     2     3     4    5      6      7      8       9        10         11        12     13       14    15    16
        %InvData = [alpha, sigma, rho, pIni, beta, rhoUA, NaN, piHigh, piPass, thetaData, growthrate, NaN, infinity, OneYear, gamma, xiUA];

        %             1     2     3           4    5   6   7      8       9          10 - 16
        InvData = [alpha, sigma, InvData(3), pIni, InvData(5:7), piHigh, piPass, InvData(10:17)];
    end
   

%% compute block 1    
    
% compute KtimesBlock1
    matlabpool open local 6
    [employmentVector,UshortVector,UlongVector,mueIniVector,effortIniVector,mueBarVector,V0,Vbs,Vw,EU] = KtimesBlock1(InvData,VarData,K);
    matlabpool close
    
% save things    
    save('KtimesBlock1') % save everything
    
%% compute the A_k, gamma and tax rate kappa    

% paras
    rho = InvData(3); xiUA = InvData(16); 
    xiUI = VarData(8,:); w = VarData(1,:); lambda = VarData(6,:); theta = VarData(7,:);

% compute the tax rate
    kappa = taxrate(w,employmentVector,xiUI,UshortVector,xiUA,UlongVector);

% compute A_k
    y0 = 1.1 * w/(1-kappa); % initial guess exceeds gross wage by 10%
    A = fsolve('block2_PRSS',y0,[],InvData,VarData,kappa,mueIniVector,effortIniVector,NaN,AwFlag,NaN);

% compute gamma
    J = (A - w/(1-kappa))./(rho + lambda); % vector with all the J_k
    gamma = J .* mueBarVector ./ theta;

%% finalizing aspects        

% check firm values
    fprintf('firm value(s) J: %g\n',J(1:K))
        
% check productivity relative to wage        
    for k = 1:K
%       fprintf('solve_PRSS: output of worker-firm pair: %g (at gross wage: %g)\n', A(k),w(k)/(1-kappa))
        if w(k)/(1-kappa) > A(k)
            display('solve_PRSS: big problem, gross wage too large')
        end
    end
    fprintf('\nsolve_PRSS: cost of a vacancy (gamma): %g\n', gamma)
    fprintf('\nsolve_PRSS: taxrate: %g\n', kappa)
%        fprintf('solve_PRSS: precision of fsolve (sum of all absolute residuals): %g\n',sum(abs(preci)))        

%% save everything
       
% write solution for A and gamma into VarData    
    VarData(2,:) = A(1:K);% solution from PRSS
    VarData(10,:) = gamma(1:K);
    
	save PRSS
    disp('PRSS found')
    
    